==> huaweicloudsdkcph-3.1.121-py2.py3-none-any.whl: huaweicloudsdkcph/v1/model/batch_import_cloud_phone_data_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchImportCloudPhoneDataRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'restore_infos': 'list[RestoreInfo]'
    }

    attribute_map = {
        'restore_infos': 'restore_infos'
    }

    def __init__(self, restore_infos=None):
        """BatchImportCloudPhoneDataRequestBody

        The model defined in huaweicloud sdk

        :param restore_infos: 待导入数据的云手机信息。
        :type restore_infos: list[:class:`huaweicloudsdkcph.v1.RestoreInfo`]
        """
        
        

        self._restore_infos = None
        self.discriminator = None

        self.restore_infos = restore_infos

    @property
    def restore_infos(self):
        """Gets the restore_infos of this BatchImportCloudPhoneDataRequestBody.

        待导入数据的云手机信息。

        :return: The restore_infos of this BatchImportCloudPhoneDataRequestBody.
        :rtype: list[:class:`huaweicloudsdkcph.v1.RestoreInfo`]
        """
        return self._restore_infos

    @restore_infos.setter
    def restore_infos(self, restore_infos):
        """Sets the restore_infos of this BatchImportCloudPhoneDataRequestBody.

        待导入数据的云手机信息。

        :param restore_infos: The restore_infos of this BatchImportCloudPhoneDataRequestBody.
        :type restore_infos: list[:class:`huaweicloudsdkcph.v1.RestoreInfo`]
        """
        self._restore_infos = restore_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchImportCloudPhoneDataRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcph-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcph/v1/model/batch_import_cloud_phone_data_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchImportCloudPhoneDataRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'restore_infos': 'list[RestoreInfo]'
    }

    attribute_map = {
        'restore_infos': 'restore_infos'
    }

    def __init__(self, restore_infos=None):
        r"""BatchImportCloudPhoneDataRequestBody

        The model defined in huaweicloud sdk

        :param restore_infos: 待导入数据的云手机信息。
        :type restore_infos: list[:class:`huaweicloudsdkcph.v1.RestoreInfo`]
        """
        
        

        self._restore_infos = None
        self.discriminator = None

        self.restore_infos = restore_infos

    @property
    def restore_infos(self):
        r"""Gets the restore_infos of this BatchImportCloudPhoneDataRequestBody.

        待导入数据的云手机信息。

        :return: The restore_infos of this BatchImportCloudPhoneDataRequestBody.
        :rtype: list[:class:`huaweicloudsdkcph.v1.RestoreInfo`]
        """
        return self._restore_infos

    @restore_infos.setter
    def restore_infos(self, restore_infos):
        r"""Sets the restore_infos of this BatchImportCloudPhoneDataRequestBody.

        待导入数据的云手机信息。

        :param restore_infos: The restore_infos of this BatchImportCloudPhoneDataRequestBody.
        :type restore_infos: list[:class:`huaweicloudsdkcph.v1.RestoreInfo`]
        """
        self._restore_infos = restore_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchImportCloudPhoneDataRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
